@@ -7,7 +7,7 @@ use Carp;
 use Log::Log4perl qw(get_logger);
 use Parse::RecDescent;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 $::RD_ERRORS = 1; # Make sure the parser dies when it encounters an error
 #$::RD_WARN   = 1; # Enable warnings. This will warn on unused rules &c.
@@ -363,6 +363,10 @@ ag_interface :
 # routes
 #
 
+#
+# routes
+#
+
 route :
 		'route' route_interface
 
@@ -374,20 +378,20 @@ route_dst :
 	|	DEFAULT_ROUTE route_nexthop
 
 route_nexthop :
-		IPADDRESS route_cost
-
-route_cost :
-		DIGIT route_options
+		IPADDRESS route_options
 
 route_options :
-		route_track
+		route_cost
+	|	route_track
 	|	route_tunneled
 	|	EOL
 	|	<error>
 
+route_cost :
+		DIGIT route_options
+
 route_track :
-		'track' DIGIT route_tunneled
-	|	'track' DIGIT
+		'track' DIGIT route_options
 
 route_tunneled :
 		TUNNELED
